@@ -172,14 +172,17 @@ if [ "${PULL_REGISTRY}" != "${PUSH_REGISTRY}" ]; then
   # Tag the bundle image
   #
   echo "Tagging bundle image ..."
+  IMAGE_BASE_NAME=$(basename ${IMAGE_NAME})
+  export CUSTOM_IMAGE=${PUSH_REGISTRY}/${IMAGE_NAMESPACE}/${IMAGE_BASE_NAME}
+  export CUSTOM_VERSION=${IMAGE_VERSION}
   docker tag \
-    ${PUSH_REGISTRY}/${IMAGE_NAMESPACE}/camel-k-bundle:${IMAGE_VERSION} \
+    $(make get-bundle-image):${CUSTOM_VERSION} \
     ${BUNDLE_IMAGE}
 
   # Push the bundle image to the registry
   #
   echo "Pushing bundle image ..."
-  docker push ${BUNDLE_IMAGE}
+  docker push ${BUNDLE_IMAGE} 2>&1
 fi
 
 #
@@ -211,10 +214,10 @@ cat << EOF >> ${CATALOG_DIR}/camel-k.yaml
 ---
 schema: olm.channel
 package: camel-k
-name: stable-dev-$(make get-version | grep -Po "\d.\d")
+name: stable-dev-$(make get-version | grep -Po "\d+\.\d+")
 entries:
-  - name: camel-k.v$(make get-version | grep -Po "\d.\d.\d")
-    replaces: $(make get-last-released-img-name).v$(make get-last-released-version | grep -Po "\d.\d.\d")
+  - name: $(make get-csv-name)
+    replaces: $(make get-last-released-img-name).v$(make get-last-released-version | grep -Po "\d+\.\d+\.\d+")
 EOF
 
 #
