@@ -23,8 +23,8 @@ package local
 import (
 	"context"
 	"io"
-	"os"
 	"strings"
+	"sync"
 	"testing"
 
 	. "github.com/onsi/gomega"
@@ -46,20 +46,83 @@ func TestLocalRun(t *testing.T) {
 
 	file := testutil.MakeTempCopy(t, "files/yaml.yaml")
 
-	kamelRun := KamelWithContext(ctx, "local", "run", file)
+	kamelRun := kamelWithContext(ctx, "local", "run", file)
 	kamelRun.SetOut(pipew)
+	kamelRun.SetErr(pipew)
 
 	logScanner := testutil.NewLogScanner(ctx, piper, "Magicstring!")
 
 	go func() {
-		err := kamelRun.Execute()
-		assert.NoError(t, err)
+		_ = kamelRun.Execute()
 		cancel()
 	}()
 
 	Eventually(logScanner.IsFound("Magicstring!"), TestTimeoutMedium).Should(BeTrue())
 }
 
+func TestLocalRunWithDependencies(t *testing.T) {
+	RegisterTestingT(t)
+
+	ctx, cancel := context.WithCancel(TestContext)
+	defer cancel()
+	piper, pipew := io.Pipe()
+	defer pipew.Close()
+	defer piper.Close()
+
+	file := testutil.MakeTempCopy(t, "files/dependency.groovy")
+
+	kamelRun := kamelWithContext(ctx, "local", "run", file, "-d", "camel-amqp")
+	kamelRun.SetOut(pipew)
+	kamelRun.SetErr(pipew)
+
+	logScanner := testutil.NewLogScanner(ctx, piper, "Magicstring!")
+
+	go func() {
+		_ = kamelRun.Execute()
+		cancel()
+	}()
+
+	Eventually(logScanner.IsFound("Magicstring!"), TestTimeoutMedium).Should(BeTrue())
+}
+
+func TestLocalRunWithInvalidDependency(t *testing.T) {
+	RegisterTestingT(t)
+
+	ctx, cancel := context.WithCancel(TestContext)
+	defer cancel()
+	piper, pipew := io.Pipe()
+	defer pipew.Close()
+	defer piper.Close()
+
+	file := testutil.MakeTempCopy(t, "files/yaml.yaml")
+
+	kamelRun := KamelWithContext(ctx, "local", "run", file,
+		"-d", "camel-xxx",
+		"-d", "mvn:org.apache.camel:camel-http:3.18.0",
+		"-d", "mvn:org.apache.camel.quarkus:camel-quarkus-netty:2.11.0")
+	kamelRun.SetOut(pipew)
+	kamelRun.SetErr(pipew)
+
+	warn1 := "Warning: dependency camel:xxx not found in Camel catalog"
+	warn2 := "Warning: do not use mvn:org.apache.camel:camel-http:3.18.0. Use camel:http instead"
+	warn3 := "Warning: do not use mvn:org.apache.camel.quarkus:camel-quarkus-netty:2.11.0. Use camel:netty instead"
+	logScanner := testutil.NewLogScanner(ctx, piper, warn1, warn2, warn3)
+
+	var wg sync.WaitGroup
+	wg.Add(1)
+	go func() {
+		defer wg.Done()
+		err := kamelRun.Execute()
+		assert.Error(t, err)
+		cancel()
+	}()
+
+	Eventually(logScanner.IsFound(warn1), TestTimeoutShort).Should(BeTrue())
+	Eventually(logScanner.IsFound(warn2), TestTimeoutShort).Should(BeTrue())
+	Eventually(logScanner.IsFound(warn3), TestTimeoutShort).Should(BeTrue())
+	wg.Wait()
+}
+
 func TestLocalRunContainerize(t *testing.T) {
 	RegisterTestingT(t)
 
@@ -72,15 +135,15 @@ func TestLocalRunContainerize(t *testing.T) {
 	file := testutil.MakeTempCopy(t, "files/yaml.yaml")
 	image := "test/test-" + strings.ToLower(util.RandomString(10))
 
-	kamelRun := KamelWithContext(ctx, "local", "run", file, "--image", image, "--containerize")
+	kamelRun := kamelWithContext(ctx, "local", "run", file, "--image", image, "--containerize")
 	kamelRun.SetOut(pipew)
+	kamelRun.SetErr(pipew)
 
 	logScanner := testutil.NewLogScanner(ctx, piper, "Magicstring!")
 
 	defer StopDockerContainers()
 	go func() {
-		err := kamelRun.Execute()
-		assert.NoError(t, err)
+		_ = kamelRun.Execute()
 		cancel()
 	}()
 
@@ -91,17 +154,13 @@ func TestLocalRunContainerize(t *testing.T) {
 func TestLocalRunIntegrationDirectory(t *testing.T) {
 	RegisterTestingT(t)
 
-	if os.Getenv("CI") == "true" {
-		t.Skip("TODO: Temporarily disabled as this test is flaky and hangs the test process")
-	}
-
 	ctx1, cancel1 := context.WithCancel(TestContext)
 	defer cancel1()
 
 	file := testutil.MakeTempCopy(t, "files/yaml.yaml")
 	dir := testutil.MakeTempDir(t)
 
-	kamelBuild := KamelWithContext(ctx1, "local", "build", file, "--integration-directory", dir)
+	kamelBuild := kamelWithContext(ctx1, "local", "build", file, "--integration-directory", dir)
 
 	go func() {
 		err := kamelBuild.Execute()
@@ -119,14 +178,14 @@ func TestLocalRunIntegrationDirectory(t *testing.T) {
 	defer pipew.Close()
 	defer piper.Close()
 
-	kamelRun := KamelWithContext(ctx2, "local", "run", "--integration-directory", dir)
+	kamelRun := kamelWithContext(ctx2, "local", "run", "--integration-directory", dir)
 	kamelRun.SetOut(pipew)
+	kamelRun.SetErr(pipew)
 
 	logScanner := testutil.NewLogScanner(ctx2, piper, "Magicstring!")
 
 	go func() {
-		err := kamelRun.Execute()
-		assert.NoError(t, err)
+		_ = kamelRun.Execute()
 		cancel2()
 	}()
 
