@@ -33,6 +33,7 @@ import (
 	"os"
 	"os/exec"
 	"reflect"
+	"runtime/debug"
 	"strings"
 	"testing"
 	"time"
@@ -94,7 +95,7 @@ var TestTimeoutMedium = 5 * time.Minute
 var TestTimeoutLong = 10 * time.Minute
 
 // TestTimeoutVeryLong should be used only for testing native builds.
-var TestTimeoutVeryLong = 60 * time.Minute
+var TestTimeoutVeryLong = 90 * time.Minute
 
 var NoOlmOperatorImage string
 
@@ -249,6 +250,27 @@ func KamelInstallWithContext(ctx context.Context, operatorID string, namespace s
 		installArgs = []string{"install", "-n", namespace, "--operator-id", operatorID}
 	}
 
+	logLevel := os.Getenv("CAMEL_K_TEST_LOG_LEVEL")
+	if len(logLevel) > 0 {
+		fmt.Printf("Setting log-level to %s\n", logLevel)
+		installArgs = append(installArgs, "--log-level", logLevel)
+	}
+
+	mvnCLIOptions := os.Getenv("CAMEL_K_TEST_MAVEN_CLI_OPTIONS")
+	if len(mvnCLIOptions) > 0 {
+		// Split the string by spaces
+		mvnCLIArr := strings.Split(mvnCLIOptions, " ")
+		for _, mc := range mvnCLIArr {
+			mc = strings.Trim(mc, " ")
+			if len(mc) == 0 {
+				continue
+			}
+
+			fmt.Printf("Adding maven cli option %s\n", mc)
+			installArgs = append(installArgs, "--maven-cli-option", mc)
+		}
+	}
+
 	installArgs = append(installArgs, args...)
 	return KamelWithContext(ctx, installArgs...)
 }
@@ -317,6 +339,12 @@ func KamelWithContext(ctx context.Context, args ...string) *cobra.Command {
 	var c *cobra.Command
 	var err error
 
+	if os.Getenv("CAMEL_K_TEST_LOG_LEVEL") == "debug" {
+		fmt.Printf("Executing kamel with command %+q\n", args)
+		fmt.Println("Printing stack for KamelWithContext")
+		debug.PrintStack()
+	}
+
 	kamelArgs := os.Getenv("KAMEL_ARGS")
 	kamelDefaultArgs := strings.Fields(kamelArgs)
 	args = append(kamelDefaultArgs, args...)
@@ -437,30 +465,34 @@ func Logs(ns, podName string, options corev1.PodLogOptions) func() string {
 	}
 }
 
-func StructuredLogs(ns, podName string, options corev1.PodLogOptions, ignoreParseErrors bool) []util.LogEntry {
-	byteReader, err := TestClient().CoreV1().Pods(ns).GetLogs(podName, &options).Stream(TestContext)
+func StructuredLogs(ns, podName string, options *corev1.PodLogOptions, ignoreParseErrors bool) ([]util.LogEntry, error) {
+
+	stream, err := TestClient().CoreV1().Pods(ns).GetLogs(podName, options).Stream(TestContext)
 	if err != nil {
-		log.Error(err, "Error while reading container logs")
-		return nil
+		msg := "Error while reading container logs"
+		log.Error(err, msg)
+		return nil, fmt.Errorf("%s: %w\n", msg, err)
 	}
 	defer func() {
-		if err := byteReader.Close(); err != nil {
+		if err := stream.Close(); err != nil {
 			log.Error(err, "Error closing the stream")
 		}
 	}()
 
 	entries := make([]util.LogEntry, 0)
-	scanner := bufio.NewScanner(byteReader)
+	scanner := bufio.NewScanner(stream)
 	for scanner.Scan() {
 		entry := util.LogEntry{}
 		t := scanner.Text()
 		err := json.Unmarshal([]byte(t), &entry)
 		if err != nil {
 			if ignoreParseErrors {
+				fmt.Printf("Warning: Ignoring parse error for logging line: %q\n", t)
 				continue
 			} else {
-				log.Errorf(err, "Unable to parse structured content: %s", t)
-				return nil
+				msg := fmt.Sprintf("Unable to parse structured content: %s", t)
+				log.Errorf(err, msg)
+				return nil, fmt.Errorf("%s %w\n", msg, err)
 			}
 		}
 
@@ -468,11 +500,18 @@ func StructuredLogs(ns, podName string, options corev1.PodLogOptions, ignorePars
 	}
 
 	if err := scanner.Err(); err != nil {
-		log.Error(err, "Error while scanning container logs")
-		return nil
+		msg := "Error while scanning container logs"
+		log.Error(err, msg)
+		return nil, fmt.Errorf("%s %w\n", msg, err)
 	}
 
-	return entries
+	if len(entries) == 0 {
+		msg := "Error fetched zero log entries"
+		log.Error(err, msg)
+		return nil, fmt.Errorf("%s %w\n", msg, err)
+	}
+
+	return entries, nil
 }
 
 func IntegrationPodPhase(ns string, name string) func() corev1.PodPhase {
@@ -601,11 +640,7 @@ func IntegrationCondition(ns string, name string, conditionType v1.IntegrationCo
 		if it == nil {
 			return nil
 		}
-		c := it.Status.GetCondition(conditionType)
-		if c == nil {
-			return nil
-		}
-		return c
+		return it.Status.GetCondition(conditionType)
 	}
 }
 
@@ -804,6 +839,24 @@ func IntegrationCronJob(ns string, name string) func() *batchv1.CronJob {
 	}
 }
 
+func Integrations(ns string) func() *v1.IntegrationList {
+	return func() *v1.IntegrationList {
+		lst := v1.NewIntegrationList()
+		if err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns)); err != nil {
+			failTest(err)
+		}
+
+		return &lst
+	}
+}
+
+func NumIntegrations(ns string) func() int {
+	return func() int {
+		lst := Integrations(ns)()
+		return len(lst.Items)
+	}
+}
+
 func Integration(ns string, name string) func() *v1.Integration {
 	return func() *v1.Integration {
 		it := v1.NewIntegration(ns, name)
@@ -1121,6 +1174,21 @@ func DeleteKits(ns string) error {
 	return nil
 }
 
+func DeleteIntegrations(ns string) func() (int, error) {
+	return func() (int, error) {
+		integrations := Integrations(ns)()
+		if len(integrations.Items) == 0 {
+			return 0, nil
+		}
+
+		if err := Kamel("delete", "--all", "-n", ns).Execute(); err != nil {
+			return 0, err
+		}
+
+		return NumIntegrations(ns)(), nil
+	}
+}
+
 func OperatorImage(ns string) func() string {
 	return func() string {
 		pod := OperatorPod(ns)()
@@ -1143,6 +1211,23 @@ func OperatorPodPhase(ns string) func() corev1.PodPhase {
 	}
 }
 
+func OperatorEnvVarValue(ns string, key string) func() string {
+	return func() string {
+		pod := OperatorPod(ns)()
+		if pod == nil || len(pod.Spec.Containers) == 0 {
+			return ""
+		}
+		envvars := pod.Spec.Containers[0].Env
+		for _, v := range envvars {
+			if v.Name == key {
+				return v.Value
+			}
+		}
+
+		return ""
+	}
+}
+
 func Configmap(ns string, name string) func() *corev1.ConfigMap {
 	return func() *corev1.ConfigMap {
 		cm := corev1.ConfigMap{
@@ -1249,6 +1334,32 @@ func CreatePlainTextSecret(ns string, name string, data map[string]string) error
 	return TestClient().Create(TestContext, &sec)
 }
 
+//
+// Finds a secret in the given namespace by name or prefix of name
+//
+func SecretByName(ns string, prefix string) func() *corev1.Secret {
+	return func() *corev1.Secret {
+		secretList, err := TestClient().CoreV1().Secrets(ns).List(TestContext, metav1.ListOptions{})
+		if err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		} else if err != nil {
+			failTest(err)
+		}
+
+		if len(secretList.Items) == 0 {
+			return nil
+		}
+
+		for _, secret := range secretList.Items {
+			if strings.HasPrefix(secret.Name, prefix) {
+				return &secret
+			}
+		}
+
+		return nil
+	}
+}
+
 func KnativeService(ns string, name string) func() *servingv1.Service {
 	return func() *servingv1.Service {
 		answer := servingv1.Service{
@@ -1416,6 +1527,32 @@ func PlatformPhase(ns string) func() v1.IntegrationPlatformPhase {
 	}
 }
 
+func PlatformCondition(
+	ns string,
+	conditionType v1.IntegrationPlatformConditionType,
+) func() *v1.IntegrationPlatformCondition {
+	return func() *v1.IntegrationPlatformCondition {
+		p := Platform(ns)()
+		if p == nil {
+			return nil
+		}
+		return p.Status.GetCondition(conditionType)
+	}
+}
+
+func PlatformConditionStatus(
+	ns string,
+	conditionType v1.IntegrationPlatformConditionType,
+) func() corev1.ConditionStatus {
+	return func() corev1.ConditionStatus {
+		c := PlatformCondition(ns, conditionType)()
+		if c == nil {
+			return "Unknown"
+		}
+		return c.Status
+	}
+}
+
 func PlatformProfile(ns string) func() v1.TraitProfile {
 	return func() v1.TraitProfile {
 		p := Platform(ns)()
@@ -2096,11 +2233,34 @@ func deleteTestNamespace(t *testing.T, ns ctrl.Object) {
 	}
 }
 
+func testNamespaceExists(ns string) (bool, error) {
+	_, err := TestClient().CoreV1().Namespaces().Get(TestContext, ns, metav1.GetOptions{})
+	if err != nil {
+		if k8serrors.IsNotFound(err) {
+			return false, nil
+		} else {
+			return false, err
+		}
+	}
+
+	return true, nil
+}
+
 func newTestNamespace(injectKnativeBroker bool) ctrl.Object {
 	brokerLabel := "eventing.knative.dev/injection"
-	name := "test-" + uuid.New().String()
+	name := os.Getenv("CAMEL_K_TEST_NS")
+	if name == "" {
+		name = "test-" + uuid.New().String()
+	}
 	c := TestClient()
 
+	if exists, err := testNamespaceExists(name); err != nil {
+		failTest(err)
+	} else if exists {
+		fmt.Println("Warning: namespace ", name, " already exists so using different namespace name")
+		name = fmt.Sprintf("%s-%d", name, time.Now().Second())
+	}
+
 	if oc, err := openshift.IsOpenShift(TestClient()); err != nil {
 		failTest(err)
 	} else if oc {
