@@ -24,7 +24,28 @@ import (
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 )
 
-// KameletBindingSpec --
+// +genclient
+// +kubebuilder:object:root=true
+// +kubebuilder:resource:path=kameletbindings,scope=Namespaced,shortName=klb,categories=kamel;camel
+// +kubebuilder:subresource:status
+// +genclient:method=GetScale,verb=get,subresource=scale,result=k8s.io/api/autoscaling/v1.Scale
+// +genclient:method=UpdateScale,verb=update,subresource=scale,input=k8s.io/api/autoscaling/v1.Scale,result=k8s.io/api/autoscaling/v1.Scale
+// +kubebuilder:subresource:scale:specpath=.spec.replicas,statuspath=.status.replicas,selectorpath=.status.selector
+// +kubebuilder:printcolumn:name="Phase",type=string,JSONPath=`.status.phase`,description="The Kamelet Binding phase"
+// +kubebuilder:printcolumn:name="Replicas",type=integer,JSONPath=`.status.replicas`,description="The number of pods"
+
+// KameletBinding is the Schema for the kamelets binding API
+type KameletBinding struct {
+	metav1.TypeMeta   `json:",inline"`
+	metav1.ObjectMeta `json:"metadata,omitempty"`
+
+	// the specification of a KameletBinding
+	Spec KameletBindingSpec `json:"spec,omitempty"`
+	// the status of a KameletBinding
+	Status KameletBindingStatus `json:"status,omitempty"`
+}
+
+// KameletBindingSpec defines the binding between a source and a sink. It can include custom parameters and additional intermediate steps and error handling.
 type KameletBindingSpec struct {
 	// Integration is an optional integration used to specify custom parameters
 	Integration *v1.IntegrationSpec `json:"integration,omitempty"`
@@ -32,15 +53,19 @@ type KameletBindingSpec struct {
 	Source Endpoint `json:"source,omitempty"`
 	// Sink is the destination of the integration defined by this binding
 	Sink Endpoint `json:"sink,omitempty"`
+	// ErrorHandler is an optional handler called upon an error occuring in the integration
+	ErrorHandler *ErrorHandlerSpec `json:"errorHandler,omitempty"`
 	// Steps contains an optional list of intermediate steps that are executed between the Source and the Sink
 	Steps []Endpoint `json:"steps,omitempty"`
+	// Replicas is the number of desired replicas for the binding
+	Replicas *int32 `json:"replicas,omitempty"`
 }
 
-// Endpoint represents a source/sink external entity
+// Endpoint represents a source/sink external entity (could be any Kubernetes resource or Camel URI)
 type Endpoint struct {
 	// Ref can be used to declare a Kubernetes resource as source/sink endpoint
 	Ref *corev1.ObjectReference `json:"ref,omitempty"`
-	// URI can alternatively be used to specify the (Camel) endpoint explicitly
+	// URI can be used to specify the (Camel) endpoint explicitly
 	URI *string `json:"uri,omitempty"`
 	// Properties are a key value representation of endpoint properties
 	Properties *EndpointProperties `json:"properties,omitempty"`
@@ -48,25 +73,37 @@ type Endpoint struct {
 	Types map[EventSlot]EventTypeSpec `json:"types,omitempty"`
 }
 
+// EndpointType represents the type (ie, source or sink)
 type EndpointType string
 
 const (
+	// EndpointTypeSource source endpoint
 	EndpointTypeSource EndpointType = "source"
+	// EndpointTypeAction action endpoint
 	EndpointTypeAction EndpointType = "action"
-	EndpointTypeSink   EndpointType = "sink"
+	// EndpointTypeSink sink endpoint
+	EndpointTypeSink EndpointType = "sink"
+	// EndpointTypeErrorHandler error handler endpoint
+	EndpointTypeErrorHandler EndpointType = "errorHandler"
 )
 
 // EndpointProperties is a key/value struct represented as JSON raw to allow numeric/boolean values
 type EndpointProperties struct {
-	v1.RawMessage `json:",inline"`
+	RawMessage `json:",inline"`
 }
 
-// KameletBindingStatus --
+// KameletBindingStatus specify the status of a binding
 type KameletBindingStatus struct {
+	// ObservedGeneration is the most recent generation observed for this KameletBinding.
+	ObservedGeneration int64 `json:"observedGeneration,omitempty"`
 	// Phase --
 	Phase KameletBindingPhase `json:"phase,omitempty"`
 	// Conditions --
 	Conditions []KameletBindingCondition `json:"conditions,omitempty"`
+	// Replicas is the number of actual replicas of the binding
+	Replicas *int32 `json:"replicas,omitempty"`
+	// Selector allows to identify pods belonging to the binding
+	Selector string `json:"selector,omitempty"`
 }
 
 // KameletBindingCondition describes the state of a resource at a certain point.
@@ -85,6 +122,7 @@ type KameletBindingCondition struct {
 	Message string `json:"message,omitempty"`
 }
 
+// KameletBindingConditionType --
 type KameletBindingConditionType string
 
 const (
@@ -92,10 +130,11 @@ const (
 	KameletBindingConditionReady KameletBindingConditionType = "Ready"
 )
 
+// KameletBindingPhase --
 type KameletBindingPhase string
 
 const (
-	// KameletKind --
+	// KameletBindingKind --
 	KameletBindingKind string = "KameletBinding"
 
 	// KameletBindingPhaseNone --
@@ -108,21 +147,6 @@ const (
 	KameletBindingPhaseReady KameletBindingPhase = "Ready"
 )
 
-// +genclient
-// +kubebuilder:object:root=true
-// +kubebuilder:resource:path=kameletbindings,scope=Namespaced,shortName=klb,categories=kamel;camel
-// +kubebuilder:subresource:status
-// +kubebuilder:printcolumn:name="Phase",type=string,JSONPath=`.status.phase`,description="The Kamelet Binding phase"
-
-// KameletBinding is the Schema for the kamelets binding API
-type KameletBinding struct {
-	metav1.TypeMeta   `json:",inline"`
-	metav1.ObjectMeta `json:"metadata,omitempty"`
-
-	Spec   KameletBindingSpec   `json:"spec,omitempty"`
-	Status KameletBindingStatus `json:"status,omitempty"`
-}
-
 // +kubebuilder:object:root=true
 
 // KameletBindingList contains a list of KameletBinding
