@@ -19,6 +19,7 @@ package cmd
 
 import (
 	"fmt"
+	"sort"
 	"strings"
 
 	"github.com/spf13/cobra"
@@ -64,7 +65,7 @@ __kamel_dependency_type() {
 		compopt -o nospace
         ;;
     *)
-        local type_list="camel mvn: file:"
+        local type_list="camel: mvn: file:"
         COMPREPLY=( $( compgen -W "${type_list}" -- "$cur") )
 	    compopt -o nospace
     esac
@@ -296,10 +297,19 @@ func computeCamelDependencies() string {
 		catalog = camel.NewRuntimeCatalog(v1.CamelCatalog{}.Spec)
 	}
 
-	results := make([]string, 0, len(catalog.Artifacts))
-	for k := range catalog.Artifacts {
-		results = append(results, k)
+	results := make([]string, 0, len(catalog.Artifacts)+len(catalog.Loaders))
+	for a := range catalog.Artifacts {
+		// skipping camel-k-* and other artifacts as they may not be useful for cli completion
+		if strings.HasPrefix(a, "camel-quarkus-") {
+			results = append(results, camel.NormalizeDependency(a))
+		}
 	}
+	for _, l := range catalog.Loaders {
+		if strings.HasPrefix(l.ArtifactID, "camel-quarkus-") {
+			results = append(results, camel.NormalizeDependency(l.ArtifactID))
+		}
+	}
+	sort.Strings(results)
 
 	return strings.Join(results, " ")
 }
