@@ -23,6 +23,7 @@ import (
 	"fmt"
 	"reflect"
 	"strconv"
+	"strings"
 
 	appsv1 "k8s.io/api/apps/v1"
 	batchv1 "k8s.io/api/batch/v1"
@@ -41,9 +42,6 @@ import (
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 )
 
-// The key used for propagating error details from Camel health to MicroProfile Health (See CAMEL-17138).
-const runtimeHealthCheckErrorMessage = "error.message"
-
 func NewMonitorAction() Action {
 	return &monitorAction{}
 }
@@ -63,35 +61,30 @@ func (action *monitorAction) CanHandle(integration *v1.Integration) bool {
 }
 
 func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integration) (*v1.Integration, error) {
+	// When in InitializationFailed condition a kit is not available for the integration
+	// so handle it differently from the rest
+	if isInInitializationFailed(integration.Status) {
+		// Only check if the Integration requires a rebuild
+		return action.checkDigestAndRebuild(integration, nil)
+	}
+
 	// At that staged the Integration must have a Kit
 	if integration.Status.IntegrationKit == nil {
 		return nil, fmt.Errorf("no kit set on integration %s", integration.Name)
 	}
 
-	kit, err := kubernetes.GetIntegrationKit(ctx, action.client, integration.Status.IntegrationKit.Name, integration.Status.IntegrationKit.Namespace)
+	kit, err := kubernetes.GetIntegrationKit(ctx, action.client,
+		integration.Status.IntegrationKit.Name, integration.Status.IntegrationKit.Namespace)
 	if err != nil {
-		return nil, fmt.Errorf("unable to find integration kit %s/%s: %w", integration.Status.IntegrationKit.Namespace, integration.Status.IntegrationKit.Name, err)
+		return nil, fmt.Errorf("unable to find integration kit %s/%s: %w",
+			integration.Status.IntegrationKit.Namespace, integration.Status.IntegrationKit.Name, err)
 	}
 
 	// Check if the Integration requires a rebuild
-	hash, err := digest.ComputeForIntegration(integration)
-	if err != nil {
+	if changed, err := action.checkDigestAndRebuild(integration, kit); err != nil {
 		return nil, err
-	}
-
-	if hash != integration.Status.Digest {
-		action.L.Info("Monitor: Integration needs a rebuild")
-
-		if v1.GetOperatorIDAnnotation(integration) != "" &&
-			(v1.GetOperatorIDAnnotation(integration) != v1.GetOperatorIDAnnotation(kit)) {
-			// Operator to reconcile the integration has changed. Reset integration kit so new operator can handle the kit reference
-			integration.SetIntegrationKit(nil)
-		}
-
-		integration.Initialize()
-		integration.Status.Digest = hash
-
-		return integration, nil
+	} else if changed != nil {
+		return changed, nil
 	}
 
 	// Check if an IntegrationKit with higher priority is ready
@@ -99,7 +92,8 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 	if !ok {
 		priority = "0"
 	}
-	withHigherPriority, err := labels.NewRequirement(v1.IntegrationKitPriorityLabel, selection.GreaterThan, []string{priority})
+	withHigherPriority, err := labels.NewRequirement(v1.IntegrationKitPriorityLabel,
+		selection.GreaterThan, []string{priority})
 	if err != nil {
 		return nil, err
 	}
@@ -159,14 +153,57 @@ func (action *monitorAction) Handle(ctx context.Context, integration *v1.Integra
 	if integration.Status.Phase == v1.IntegrationPhaseDeploying {
 		integration.Status.Phase = v1.IntegrationPhaseRunning
 	}
-	err = action.updateIntegrationPhaseAndReadyCondition(ctx, environment, integration, pendingPods.Items, runningPods.Items)
-	if err != nil {
+	if err = action.updateIntegrationPhaseAndReadyCondition(
+		ctx, environment, integration, pendingPods.Items, runningPods.Items,
+	); err != nil {
 		return nil, err
 	}
 
 	return integration, nil
 }
 
+func isInInitializationFailed(status v1.IntegrationStatus) bool {
+	if status.Phase != v1.IntegrationPhaseError {
+		return false
+	}
+	if cond := status.GetCondition(v1.IntegrationConditionReady); cond != nil {
+		if cond.Status == corev1.ConditionFalse &&
+			cond.Reason == v1.IntegrationConditionInitializationFailedReason {
+			return true
+		}
+	}
+
+	return false
+}
+
+func (action *monitorAction) checkDigestAndRebuild(
+	integration *v1.Integration, kit *v1.IntegrationKit,
+) (*v1.Integration, error) {
+	hash, err := digest.ComputeForIntegration(integration)
+	if err != nil {
+		return nil, err
+	}
+
+	if hash != integration.Status.Digest {
+		action.L.Info("Monitor: Integration needs a rebuild")
+
+		if kit != nil &&
+			v1.GetOperatorIDAnnotation(integration) != "" &&
+			v1.GetOperatorIDAnnotation(integration) != v1.GetOperatorIDAnnotation(kit) {
+			// Operator to reconcile the integration has changed. Reset integration kit
+			// so new operator can handle the kit reference
+			integration.SetIntegrationKit(nil)
+		}
+
+		integration.Initialize()
+		integration.Status.Digest = hash
+
+		return integration, nil
+	}
+
+	return nil, nil
+}
+
 type controller interface {
 	checkReadyCondition(ctx context.Context) (bool, error)
 	getPodSpec() corev1.PodSpec
@@ -177,7 +214,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 	var controller controller
 	var obj ctrl.Object
 	switch {
-	case isConditionTrue(integration, v1.IntegrationConditionDeploymentAvailable):
+	case integration.IsConditionTrue(v1.IntegrationConditionDeploymentAvailable):
 		obj = getUpdatedController(env, &appsv1.Deployment{})
 		deploy, ok := obj.(*appsv1.Deployment)
 		if !ok {
@@ -187,7 +224,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 			obj:         deploy,
 			integration: integration,
 		}
-	case isConditionTrue(integration, v1.IntegrationConditionKnativeServiceAvailable):
+	case integration.IsConditionTrue(v1.IntegrationConditionKnativeServiceAvailable):
 		obj = getUpdatedController(env, &servingv1.Service{})
 		svc, ok := obj.(*servingv1.Service)
 		if !ok {
@@ -197,7 +234,7 @@ func (action *monitorAction) newController(env *trait.Environment, integration *
 			obj:         svc,
 			integration: integration,
 		}
-	case isConditionTrue(integration, v1.IntegrationConditionCronJobAvailable):
+	case integration.IsConditionTrue(v1.IntegrationConditionCronJobAvailable):
 		obj = getUpdatedController(env, &batchv1.CronJob{})
 		cj, ok := obj.(*batchv1.CronJob)
 		if !ok {
@@ -226,13 +263,21 @@ func getUpdatedController(env *trait.Environment, obj ctrl.Object) ctrl.Object {
 	})
 }
 
-func (action *monitorAction) updateIntegrationPhaseAndReadyCondition(ctx context.Context, environment *trait.Environment, integration *v1.Integration, pendingPods []corev1.Pod, runningPods []corev1.Pod) error {
+func (action *monitorAction) updateIntegrationPhaseAndReadyCondition(
+	ctx context.Context, environment *trait.Environment, integration *v1.Integration,
+	pendingPods []corev1.Pod, runningPods []corev1.Pod,
+) error {
 	controller, err := action.newController(environment, integration)
 	if err != nil {
 		return err
 	}
 
+	readyPods, unreadyPods := filterPodsByReadyStatus(runningPods, controller.getPodSpec())
+
 	if done, err := controller.checkReadyCondition(ctx); done || err != nil {
+		// There may be pods that are not ready but still probable for getting error messages.
+		// Ignore returned error from probing as it's expected when the ctrl obj is not ready.
+		_ = action.probeReadiness(ctx, environment, integration, unreadyPods)
 		return err
 	}
 	if done := checkPodStatuses(integration, pendingPods, runningPods); done {
@@ -240,7 +285,6 @@ func (action *monitorAction) updateIntegrationPhaseAndReadyCondition(ctx context
 	}
 	integration.Status.Phase = v1.IntegrationPhaseRunning
 
-	readyPods, unreadyPods := filterPodsByReadyStatus(runningPods, controller.getPodSpec())
 	if done := controller.updateReadyCondition(readyPods); done {
 		return nil
 	}
@@ -255,9 +299,11 @@ func checkPodStatuses(integration *v1.Integration, pendingPods []corev1.Pod, run
 	// Check Pods statuses
 	for _, pod := range pendingPods {
 		// Check the scheduled condition
-		if scheduled := kubernetes.GetPodCondition(pod, corev1.PodScheduled); scheduled != nil && scheduled.Status == corev1.ConditionFalse && scheduled.Reason == "Unschedulable" {
+		if scheduled := kubernetes.GetPodCondition(pod, corev1.PodScheduled); scheduled != nil &&
+			scheduled.Status == corev1.ConditionFalse &&
+			scheduled.Reason == "Unschedulable" {
 			integration.Status.Phase = v1.IntegrationPhaseError
-			setReadyConditionError(integration, scheduled.Message)
+			integration.SetReadyConditionError(scheduled.Message)
 			return true
 		}
 	}
@@ -270,7 +316,7 @@ func checkPodStatuses(integration *v1.Integration, pendingPods []corev1.Pod, run
 			// Check the images are pulled
 			if waiting := container.State.Waiting; waiting != nil && waiting.Reason == "ImagePullBackOff" {
 				integration.Status.Phase = v1.IntegrationPhaseError
-				setReadyConditionError(integration, waiting.Message)
+				integration.SetReadyConditionError(waiting.Message)
 				return true
 			}
 		}
@@ -287,12 +333,12 @@ func checkPodStatuses(integration *v1.Integration, pendingPods []corev1.Pod, run
 			// Check the container state
 			if waiting := container.State.Waiting; waiting != nil && waiting.Reason == "CrashLoopBackOff" {
 				integration.Status.Phase = v1.IntegrationPhaseError
-				setReadyConditionError(integration, waiting.Message)
+				integration.SetReadyConditionError(waiting.Message)
 				return true
 			}
 			if terminated := container.State.Terminated; terminated != nil && terminated.Reason == "Error" {
 				integration.Status.Phase = v1.IntegrationPhaseError
-				setReadyConditionError(integration, terminated.Message)
+				integration.SetReadyConditionError(terminated.Message)
 				return true
 			}
 		}
@@ -372,7 +418,10 @@ func findIntegrationContainer(spec corev1.PodSpec) *corev1.Container {
 }
 
 // probeReadiness calls the readiness probes of the non-ready Pods directly to retrieve insights from the Camel runtime.
-func (action *monitorAction) probeReadiness(ctx context.Context, environment *trait.Environment, integration *v1.Integration, unreadyPods []corev1.Pod) error {
+func (action *monitorAction) probeReadiness(
+	ctx context.Context, environment *trait.Environment, integration *v1.Integration,
+	unreadyPods []corev1.Pod,
+) error {
 	var runtimeNotReadyMessages []string
 	for i := range unreadyPods {
 		pod := &unreadyPods[i]
@@ -389,11 +438,13 @@ func (action *monitorAction) probeReadiness(ctx context.Context, environment *tr
 				continue
 			}
 			if errors.Is(err, context.DeadlineExceeded) {
-				runtimeNotReadyMessages = append(runtimeNotReadyMessages, fmt.Sprintf("readiness probe timed out for Pod %s/%s", pod.Namespace, pod.Name))
+				runtimeNotReadyMessages = append(runtimeNotReadyMessages,
+					fmt.Sprintf("readiness probe timed out for Pod %s/%s", pod.Namespace, pod.Name))
 				continue
 			}
 			if !k8serrors.IsServiceUnavailable(err) {
-				runtimeNotReadyMessages = append(runtimeNotReadyMessages, fmt.Sprintf("readiness probe failed for Pod %s/%s: %s", pod.Namespace, pod.Name, err.Error()))
+				runtimeNotReadyMessages = append(runtimeNotReadyMessages,
+					fmt.Sprintf("readiness probe failed for Pod %s/%s: %s", pod.Namespace, pod.Name, err.Error()))
 				continue
 			}
 			health, err := NewHealthCheck(body)
@@ -401,13 +452,14 @@ func (action *monitorAction) probeReadiness(ctx context.Context, environment *tr
 				return err
 			}
 			for _, check := range health.Checks {
-				if check.Status == HealthCheckStateUp {
+				if check.Status == HealthCheckStatusUp {
 					continue
 				}
-				if _, ok := check.Data[runtimeHealthCheckErrorMessage]; ok {
+				if _, ok := check.Data[HealthCheckErrorMessage]; ok {
 					integration.Status.Phase = v1.IntegrationPhaseError
 				}
-				runtimeNotReadyMessages = append(runtimeNotReadyMessages, fmt.Sprintf("Pod %s runtime is not ready: %s", pod.Name, check.Data))
+				runtimeNotReadyMessages = append(runtimeNotReadyMessages,
+					fmt.Sprintf("Pod %s runtime is not ready: %s", pod.Name, check.Data))
 			}
 		}
 	}
@@ -416,7 +468,8 @@ func (action *monitorAction) probeReadiness(ctx context.Context, environment *tr
 		if integration.Status.Phase == v1.IntegrationPhaseError {
 			reason = v1.IntegrationConditionErrorReason
 		}
-		setReadyCondition(integration, corev1.ConditionFalse, reason, fmt.Sprintf("%s", runtimeNotReadyMessages))
+		message := fmt.Sprintf("[%s]", strings.Join(runtimeNotReadyMessages, ", "))
+		integration.SetReadyCondition(corev1.ConditionFalse, reason, message)
 	}
 
 	return nil
@@ -453,19 +506,3 @@ func getIntegrationContainer(environment *trait.Environment, pod *corev1.Pod) *c
 	}
 	return nil
 }
-
-func isConditionTrue(integration *v1.Integration, conditionType v1.IntegrationConditionType) bool {
-	cond := integration.Status.GetCondition(conditionType)
-	if cond == nil {
-		return false
-	}
-	return cond.Status == corev1.ConditionTrue
-}
-
-func setReadyConditionError(integration *v1.Integration, err string) {
-	setReadyCondition(integration, corev1.ConditionFalse, v1.IntegrationConditionErrorReason, err)
-}
-
-func setReadyCondition(integration *v1.Integration, status corev1.ConditionStatus, reason string, message string) {
-	integration.Status.SetCondition(v1.IntegrationConditionReady, status, reason, message)
-}
