@@ -104,7 +104,11 @@ func (t *builderTrait) Apply(e *Environment) error {
 		} else {
 			t.L.Infof("User defined %s platform, will be used from buildah!", platform)
 		}
-
+		var executorImage string
+		if image, found := e.Platform.Status.Build.PublishStrategyOptions[builder.BuildahImage]; found {
+			executorImage = image
+			t.L.Infof("User defined executor image %s will be used for buildah", image)
+		}
 		e.BuildTasks = append(e.BuildTasks, v1.Task{Buildah: &v1.BuildahTask{
 			Platform: platform,
 			BaseTask: v1.BaseTask{
@@ -114,19 +118,18 @@ func (t *builderTrait) Apply(e *Environment) error {
 				Image:    getImageName(e),
 				Registry: e.Platform.Status.Build.Registry,
 			},
-			Verbose: t.Verbose,
+			Verbose:       t.Verbose,
+			ExecutorImage: executorImage,
 		}})
-	// nolint: staticcheck
+	//nolint: staticcheck,nolintlint
 	case v1.IntegrationPlatformBuildPublishStrategyKaniko:
-		var persistentVolumeClaim string
-		var found, cacheEnabled bool
-		if persistentVolumeClaim, found = e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoPVCName]; !found {
-			persistentVolumeClaim = e.Platform.Status.Build.PersistentVolumeClaim
-		}
+		persistentVolumeClaim := e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoPVCName]
+		cacheEnabled := e.Platform.Status.Build.IsOptionEnabled(builder.KanikoBuildCacheEnabled)
 
-		cacheEnabled = e.Platform.Status.Build.IsOptionEnabled(builder.KanikoBuildCacheEnabled)
-		if _, found = e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoBuildCacheEnabled]; !found {
-			cacheEnabled = *e.Platform.Status.Build.KanikoBuildCache
+		var executorImage string
+		if image, found := e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoExecutorImage]; found {
+			executorImage = image
+			t.L.Infof("User defined executor image %s will be used for kaniko", image)
 		}
 
 		e.BuildTasks = append(e.BuildTasks, v1.Task{Kaniko: &v1.KanikoTask{
@@ -141,7 +144,8 @@ func (t *builderTrait) Apply(e *Environment) error {
 				Enabled:               &cacheEnabled,
 				PersistentVolumeClaim: persistentVolumeClaim,
 			},
-			Verbose: t.Verbose,
+			Verbose:       t.Verbose,
+			ExecutorImage: executorImage,
 		}})
 	}
 
