@@ -24,6 +24,7 @@ import (
 	"strings"
 
 	"github.com/pkg/errors"
+
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -48,6 +49,11 @@ func newCamelTrait() Trait {
 	}
 }
 
+// IsPlatformTrait overrides base class method.
+func (t *camelTrait) IsPlatformTrait() bool {
+	return true
+}
+
 // InfluencesKit overrides base class method.
 func (t *camelTrait) InfluencesKit() bool {
 	return true
@@ -58,19 +64,25 @@ func (t *camelTrait) Configure(e *Environment) (bool, error) {
 		return false, errors.New("trait camel cannot be disabled")
 	}
 
+	if t.RuntimeVersion == "" {
+		t.RuntimeVersion = determineRuntimeVersion(e)
+	}
+
 	return true, nil
 }
 
 func (t *camelTrait) Apply(e *Environment) error {
-	rv := t.determineRuntimeVersion(e)
+	if t.RuntimeVersion == "" {
+		return errors.New("unable to determine runtime version")
+	}
 
 	if e.CamelCatalog == nil {
-		if err := t.loadOrCreateCatalog(e, rv); err != nil {
+		if err := t.loadOrCreateCatalog(e, t.RuntimeVersion); err != nil {
 			return err
 		}
 	}
 
-	e.RuntimeVersion = rv
+	e.RuntimeVersion = t.RuntimeVersion
 
 	if e.Integration != nil {
 		e.Integration.Status.RuntimeVersion = e.CamelCatalog.Runtime.Version
@@ -160,24 +172,6 @@ func (t *camelTrait) loadOrCreateCatalog(e *Environment, runtimeVersion string)
 	return nil
 }
 
-func (t *camelTrait) determineRuntimeVersion(e *Environment) string {
-	if t.RuntimeVersion != "" {
-		return t.RuntimeVersion
-	}
-	if e.Integration != nil && e.Integration.Status.RuntimeVersion != "" {
-		return e.Integration.Status.RuntimeVersion
-	}
-	if e.IntegrationKit != nil && e.IntegrationKit.Status.RuntimeVersion != "" {
-		return e.IntegrationKit.Status.RuntimeVersion
-	}
-	return e.Platform.Status.Build.RuntimeVersion
-}
-
-// IsPlatformTrait overrides base class method.
-func (t *camelTrait) IsPlatformTrait() bool {
-	return true
-}
-
 func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 	sources := e.Integration.Sources()
 	maps := make([]ctrl.Object, 0, len(sources)+1)
@@ -253,53 +247,18 @@ func (t *camelTrait) computeConfigMaps(e *Environment) []ctrl.Object {
 		maps = append(maps, &cm)
 	}
 
-	for i, r := range e.Integration.Spec.Resources {
-		if r.Type == v1.ResourceTypeOpenAPI {
-			continue
-		}
-		if r.ContentRef != "" {
-			continue
-		}
-
-		cmKey := "content"
-		if r.ContentKey != "" {
-			cmKey = r.ContentKey
-		}
-
-		cm := corev1.ConfigMap{
-			TypeMeta: metav1.TypeMeta{
-				Kind:       "ConfigMap",
-				APIVersion: "v1",
-			},
-			ObjectMeta: metav1.ObjectMeta{
-				Name:      fmt.Sprintf("%s-resource-%03d", e.Integration.Name, i),
-				Namespace: e.Integration.Namespace,
-				Labels: map[string]string{
-					"camel.apache.org/integration": e.Integration.Name,
-				},
-				Annotations: map[string]string{
-					"camel.apache.org/resource.name":        r.Name,
-					"camel.apache.org/resource.compression": strconv.FormatBool(r.Compression),
-				},
-			},
-		}
-
-		if r.ContentType != "" {
-			cm.Annotations["camel.apache.org/resource.content-type"] = r.ContentType
-		}
-
-		if r.RawContent != nil {
-			cm.BinaryData = map[string][]byte{
-				cmKey: r.RawContent,
-			}
-		} else {
-			cm.Data = map[string]string{
-				cmKey: r.Content,
-			}
-		}
-
-		maps = append(maps, &cm)
-	}
-
 	return maps
 }
+
+func determineRuntimeVersion(e *Environment) string {
+	if e.Integration != nil && e.Integration.Status.RuntimeVersion != "" {
+		return e.Integration.Status.RuntimeVersion
+	}
+	if e.IntegrationKit != nil && e.IntegrationKit.Status.RuntimeVersion != "" {
+		return e.IntegrationKit.Status.RuntimeVersion
+	}
+	if e.Platform != nil && e.Platform.Status.Build.RuntimeVersion != "" {
+		return e.Platform.Status.Build.RuntimeVersion
+	}
+	return ""
+}
